@@ -1,12 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2019-2020 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2019-2021 Montel Laurent <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
-
-#ifndef MARKUPDIRECTOR_H
-#define MARKUPDIRECTOR_H
+#pragma once
 
 #include "abstractmarkupbuilder.h"
 #include "kpimtextedit_export.h"
@@ -137,7 +135,7 @@ public:
     block. If calling this method directly, an invalid QTextFrame::iterator
     may be used.
   */
-    virtual Q_REQUIRED_RESULT QTextFrame::iterator processBlockContents(QTextFrame::iterator it, const QTextBlock &block);
+    virtual QTextFrame::iterator processBlockContents(QTextFrame::iterator it, const QTextBlock &block);
 
     /**
     Hook for instructing the builder to create output for the @p fragemnt with
@@ -267,4 +265,3 @@ private:
 };
 }
 
-#endif
