@@ -115,10 +115,7 @@ RichTextEditor::RichTextEditor(QWidget *parent)
     d->mInitialFontSize = font().pointSize();
 }
 
-RichTextEditor::~RichTextEditor()
-{
-    delete d;
-}
+RichTextEditor::~RichTextEditor() = default;
 
 void RichTextEditor::setDefaultFontSize(int val)
 {
@@ -165,7 +162,7 @@ QMenu *RichTextEditor::mousePopupMenu(QPoint pos)
     if (popup) {
         const bool emptyDocument = document()->isEmpty();
         if (!isReadOnly()) {
-            QList<QAction *> actionList = popup->actions();
+            const QList<QAction *> actionList = popup->actions();
             enum { UndoAct, RedoAct, CutAct, CopyAct, PasteAct, ClearAct, SelectAllAct, NCountActs };
             QAction *separatorAction = nullptr;
             const int idx = actionList.indexOf(actionList[SelectAllAct]) + 1;
@@ -439,7 +436,12 @@ void RichTextEditor::checkSpelling(bool force)
     auto backgroundSpellCheck = new Sonnet::BackgroundChecker;
     if (backgroundSpellCheck->speller().availableBackends().isEmpty()) {
         if (force) {
-            if (KMessageBox::Yes == KMessageBox::questionYesNo(this, i18n("No backend available for spell checking. Do you want to send the email anyways?"))) {
+            const int answer = KMessageBox::questionYesNo(this,
+                                                          i18n("No backend available for spell checking. Do you want to send the email anyways?"),
+                                                          QString(),
+                                                          KGuiItem(i18nc("@action:button", "Send"), QStringLiteral("mail-send")),
+                                                          KStandardGuiItem::cancel());
+            if (answer == KMessageBox::Yes) {
                 Q_EMIT spellCheckingFinished();
             }
         } else {
